@@ -191,6 +191,16 @@ def is_single_not_none(*args) -> bool:
     :return: True if exactly one of the arguments is not None
     """
     res = 0
+    for arg in args:
+        res += int(arg is not None)
+    return res == 1
+
+
+def is_single_none(*args) -> bool:
+    """
+    :return: True if exactly one of the arguments is None
+    """
+    res = 0
     for arg in args:
         res += int(arg is None)
     return res == 1
